==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/DumbPointerAnalysis.h <==
// public class soot.jimple.toolkits.pointer.DumbPointerAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9bc4ec20ce3c692 soot_jimple_toolkits_pointer_DumbPointerAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DumbPointerAnalysis_H_
#define _JC_soot_jimple_toolkits_pointer_DumbPointerAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_PointsToSet$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootField$object;
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$13399f75330ed05c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$fbb06c2cbd1c9275(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$7b21a48ed244ee19(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$80f21c0ae444060e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_soot_SootField$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjectsOfArrayElement$7da6aa8eb6b5d138(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$13399f75330ed05c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$fbb06c2cbd1c9275;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$7b21a48ed244ee19;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$80f21c0ae444060e;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjectsOfArrayElement$7da6aa8eb6b5d138;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$v$12bec1de6156bb05(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods {
	struct _jc_object	*(*reachingObjects$13399f75330ed05c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *);
	struct _jc_object	*(*reachingObjects$fbb06c2cbd1c9275)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *);
	struct _jc_object	*(*reachingObjects$7b21a48ed244ee19)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *);
	struct _jc_object	*(*reachingObjects$80f21c0ae444060e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_soot_SootField$object *);
	struct _jc_object	*(*reachingObjectsOfArrayElement$7da6aa8eb6b5d138)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods	soot_jimple_toolkits_pointer_DumbPointerAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs {
    _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs	soot_jimple_toolkits_pointer_DumbPointerAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs	soot_jimple_toolkits_pointer_DumbPointerAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object {
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DumbPointerAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DumbPointerAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/DumbPointerAnalysis.h <==
// public class soot.jimple.toolkits.pointer.DumbPointerAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9bc4ec20ce3c692 soot_jimple_toolkits_pointer_DumbPointerAnalysis

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_DumbPointerAnalysis_H_
#define _JC_soot_jimple_toolkits_pointer_DumbPointerAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Local$object;
struct _jc_soot_PointsToSet$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootField$object;
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$13399f75330ed05c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$fbb06c2cbd1c9275(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$7b21a48ed244ee19(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjects$80f21c0ae444060e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$reachingObjectsOfArrayElement$7da6aa8eb6b5d138(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$13399f75330ed05c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$fbb06c2cbd1c9275;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$7b21a48ed244ee19;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjects$80f21c0ae444060e;
extern _jc_method _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method_info$reachingObjectsOfArrayElement$7da6aa8eb6b5d138;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$method$v$12bec1de6156bb05(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods {
	struct _jc_object	*(*reachingObjects$13399f75330ed05c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*reachingObjects$fbb06c2cbd1c9275)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*reachingObjects$7b21a48ed244ee19)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*reachingObjects$80f21c0ae444060e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_soot_SootField$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*reachingObjectsOfArrayElement$7da6aa8eb6b5d138)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vmethods	soot_jimple_toolkits_pointer_DumbPointerAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs {
    _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_refs	soot_jimple_toolkits_pointer_DumbPointerAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$sub_nonrefs	soot_jimple_toolkits_pointer_DumbPointerAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$object {
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$vtype _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_DumbPointerAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_DumbPointerAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_DumbPointerAnalysis_H_ */
